==> syncope-2.0.10-source-release.zip: syncope-2.0.10/core/provisioning-java/src/main/java/org/apache/syncope/core/provisioning/java/DefaultLogicActions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.provisioning.java;

import org.apache.syncope.common.lib.patch.AnyPatch;
import org.apache.syncope.common.lib.to.AnyTO;
import org.apache.syncope.core.provisioning.api.LogicActions;

public class DefaultLogicActions implements LogicActions {

    @Override
    public <A extends AnyTO> A beforeCreate(final A input) {
        return input;
    }

    @Override
    public <A extends AnyTO> A afterCreate(final A input) {
        return input;
    }

    @Override
    public <P extends AnyPatch> P beforeUpdate(final P input) {
        return input;
    }

    @Override
    public <A extends AnyTO> A afterUpdate(final A input) {
        return input;
    }

    @Override
    public <A extends AnyTO> A beforeDelete(final A input) {
        return input;
    }

    @Override
    public <A extends AnyTO> A afterDelete(final A input) {
        return input;
    }

}

==> syncope-2.0.13-source-release.zip: syncope-2.0.13/core/provisioning-java/src/main/java/org/apache/syncope/core/provisioning/java/DefaultLogicActions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.provisioning.java;

import java.util.List;
import org.apache.syncope.common.lib.patch.AnyPatch;
import org.apache.syncope.common.lib.to.AnyTO;
import org.apache.syncope.common.lib.to.PropagationStatus;
import org.apache.syncope.core.provisioning.api.LogicActions;

public class DefaultLogicActions implements LogicActions {

    @Override
    public <A extends AnyTO> A beforeCreate(final A input) {
        return input;
    }

    @Override
    public <A extends AnyTO> A afterCreate(final A input, final List<PropagationStatus> statuses) {
        return input;
    }

    @Override
    public <P extends AnyPatch> P beforeUpdate(final P input) {
        return input;
    }

    @Override
    public <A extends AnyTO> A afterUpdate(final A input, final List<PropagationStatus> statuses) {
        return input;
    }

    @Override
    public <A extends AnyTO> A beforeDelete(final A input) {
        return input;
    }

    @Override
    public <A extends AnyTO> A afterDelete(final A input, final List<PropagationStatus> statuses) {
        return input;
    }

}
